/* POVRAY DESCRIPTION FILE
   SCENE DESCRIPTION : An architectural interior in the Romanesque style.
                       The intent is to create a romantic interior of endless
                       volume.
   DATE CREATED : 14.10.95
   AUTHOR : Nathan O'Brien
            33/392 Jones St Ultimo 2007 Australia
            phone : 612 966 01102  (AH) 
            fax   : 612 261 8932
            email : no13@ozemail.com.au
   RENDERING TIME : 23 hours on a Pentium 90 with 16Mb of RAM.
                    Output file : 640 x 480
                    Rendering options : +a
*/

#include "colors.inc"
#include "textures.inc"
#include "stones.inc"
#include "fov.inc"

camera {
        location <5000,3000,-7000>
        look_at  <2000,3000,0>
        direction <0,0,FoV_120>
}

light_source {<5000,4000,-7000> color Gray80}
light_source {<6000,20000,-8000> color White}

/* NON 'WHITE' LIGHT SOURCE */

#declare soft_light = color red .28 green .21 blue .09

/* THE BLACK/WHITE BANDED TEXTURE */

#declare tex3=
texture{pigment{
        gradient y
        color_map{
        [0.1  color rgbf <1,1,1,.75>]
        [0.25 color rgbf <1,1,1,.75>]
        [0.25 color rgbf <0,0,0,.3>]
        [0.75 color rgbf <0,0,0,.3>]
        [0.75 color rgbf <1,1,1,.75>]
        [1.0  color rgbf <1,1,1,.75>]
        }
        scale <800,800,800>
}}

/* THE ARCH */

#declare arch_part=
difference {
        box {<-2037,2192,300><3963,5300,-300>}
        cylinder {<0,0,400><0,0,-400>,4099}
        box {<-100,0,400><7000,1800,-400> rotate <0,0,-15> translate <-2037,5300,0>}
        box {<-2500,3800,400><-1000,2300,-400>}
}

#declare arch=
union {
object {arch_part texture{Stone8 scale<600,600,600>} texture{tex3 rotate <0,0,75>}}
difference {
        box {<-2037,3692,220><3963,5559,-220> texture{Stone8 scale<600,600,600>}}
        box {<-100,0,400><7000,1800,-400> rotate <0,0,-15> translate <-2037,5559,0> texture{Stone8 scale<600,600,600>}}
        box {<-100,0,400><7000,-3000,-400> rotate <0,0,-15> translate <-2037,5300,0> texture{Stone8 scale<600,600,600>}}
}
box {<-2037,5693,220><-1537,5424,-220> texture{Stone8 scale<600,600,600>}}
box {<3463,4085,220><3963,3951,-220> texture{Stone8 scale<600,600,600>}}
}

/* THE COLUMN */

#declare entab1=
union{
        box {<-150,0,-150><150,50,150>}
        box {<-165,50,-165><165,100,165>}
        box {<-180,100,-180><180,175,180>}
        box {<-195,175,-195><195,190,195>}
        box {<-210,190,-210><210,205,210>}
        box {<-195,205,-195><195,445,195>}
        box {<-210,445,-210><210,470,210>}
        box {<-260,520,-260><260,570,260>}
        box {<-275,570,-275><275,585,275>}
        box {<-290,585,-290><290,600,290>}
        difference {
                box {<-260,470,-260><260,520,260>}
                box {<0,1000,1000><1000,-1000,-1000> rotate <0,0,-45> translate <210,470,0>}
                box {<0,1000,1000><1000,-1000,-1000> rotate <0,0,-45> translate <210,470,0> rotate <0,90,0>}
                box {<0,1000,1000><1000,-1000,-1000> rotate <0,0,-45> translate <210,470,0> rotate <0,180,0>}
                box {<0,1000,1000><1000,-1000,-1000> rotate <0,0,-45> translate <210,470,0> rotate <0,270,0>}
        }
}

#declare entab2=
union{
        box {<-200,255,-200><200,280,200>}
        box {<-100,230,-210><-50,445,210>}
        box {<-25,230,-210><25,445,210>}
        box {<50,230,-210><100,445,210>}
        box {<-210,230,-100><210,445,-50>}
        box {<-210,230,-25><210,445,25>}
        box {<-210,230,50><210,445,100>}
        box {<-25,470,-275><25,555,275>}
        box {<-275,470,-25><275,555,25>}
        box {<-40,555,-290><40,570,290>}
        box {<-290,555,-40><290,570,40>}
}

#declare entab=
union{
object {entab1}
object {entab2 texture {Stone13 scale <600,600,600>}}
}

#declare column_head=
union{
        difference {
                cylinder {<150,75,170><150,75,50>,75}
                box {<150,170,180><0,-30,40>}
                torus {62.5,15 sturm rotate <90,0,0> translate <150,75,170>}
                torus {37.5,15 sturm rotate <90,0,0> translate <150,75,170>}
                torus {12.5,15 sturm rotate <90,0,0> translate <150,75,170>}
        }
        difference {
                cylinder {<150,62.5,170><150,62.5,50>,62.5}
                box {<150,170,180><250,-30,40>}
                torus {50,15 sturm rotate <90,0,0> translate <150,62.5,170>}
                torus {25,15 sturm rotate <90,0,0> translate <150,62.5,170>}
        }
}

#declare head_half=
union{
        difference {
                box {<-150,125,170><150,150,75>}
                cylinder {<-175,137.5,170><175,137.5,170>,15}
        }
        object {column_head}
        object {column_head scale <-1,1,1>}
}

#declare capital=
union {
        object {head_half}
        object {head_half scale <1,1,-1>}
}

#declare cut_out=
merge{
cylinder {<150,250,0><150,2195,0>,25}
sphere {<150,250,0>,25}
sphere {<150,2195,0>,25}
sphere {<160,2305,0>,25}
}

#declare column=
union{
box {<-200,0,-200><200,50,200>}
torus {175,25 sturm translate <0,75,0>}
cylinder {<0,100,0><0,115,0>,175}
difference {
        cylinder {<0,115,0><0,155,0>,175}
        torus {175,20 sturm translate <0,135,0>}
}
cylinder {<0,155,0><0,170,0>,175}
cylinder {<0,170,0><0,185,0>,165}
difference {
        cylinder {<0,185,0><0,2385,0>,150}
        object {cut_out}
        object {cut_out rotate <0,22.5,0>}
        object {cut_out rotate <0,45,0>}   
        object {cut_out rotate <0,67.5,0>} 
        object {cut_out rotate <0,90,0>} 
        object {cut_out rotate <0,112.5,0>} 
        object {cut_out rotate <0,135,0>} 
        object {cut_out rotate <0,157.5,0>} 
        object {cut_out rotate <0,180,0>} 
        object {cut_out rotate <0,202.5,0>} 
        object {cut_out rotate <0,225,0>} 
        object {cut_out rotate <0,247.5,0>} 
        object {cut_out rotate <0,270,0>} 
        object {cut_out rotate <0,292.5,0>} 
        object {cut_out rotate <0,315,0>} 
        object {cut_out rotate <0,337.5,0>} 
}   
box {<165,2385,165><-165,2400,-165>}
object {capital translate <0,2220,0>}
object {entab translate <0,2400,0>}
}

/* THE BALUSTRADE */

#declare piece=
union{
        box {<-200,25,-200><200,50,200>}
        torus {175,25 sturm translate <0,75,0>}
        difference {
                cylinder {<0,100,0><0,975,0>,125}
                torus {125,75 sturm translate <0,175,0>}
                torus {125,75 sturm translate <0,900,0>}
        }
        sphere {<0,537.5,0>,237.5}
        torus {175,25 sturm translate <0,1000,0>}
        box {<-200,1025,-200><200,1050,200>}
}

#declare balustrade=
union{
        box {<-225,0,0><225,25,4400>}
        box {<200,1050,0><200,1075,4400>}
        box {<225,1075,0><225,1175,4400>}
        box {<200,1175,0><200,1200,4400>}
        object {piece texture {Stone16 scale <600,600,600>} translate <0,0,400>}
        object {piece texture {Stone16 scale <600,600,600>} translate <0,0,1000>}
        object {piece texture {Stone16 scale <600,600,600>} translate <0,0,1600>}
        object {piece texture {Stone16 scale <600,600,600>} translate <0,0,2200>}
        object {piece texture {Stone16 scale <600,600,600>} translate <0,0,2800>}
        object {piece texture {Stone16 scale <600,600,600>} translate <0,0,3400>}
        object {piece texture {Stone16 scale <600,600,600>} translate <0,0,4000>}
}

/* THE STAIR CASE */

#declare tread=
union {
        box {<0,0,0><450,-200,4500>}
        cylinder {<450,-25,0><450,-25,4500>,25}
        object {piece texture {Stone16 scale<600,600,600>} translate <225,-25,4275>}
        object {piece texture {Stone16 scale<600,600,600>} translate <225,-25,225>}
        box {<-200,1025,-200><200,1203,200> texture{Stone16 scale<600,600,600>} translate <225,0,4275>}
        box {<-200,1025,-200><200,1203,200> texture{Stone16 scale<600,600,600>} translate <225,0,225>}
}

#declare rail=
union{
        box {<0,0,-200><8300,25,200>}
        box {<0,25,-225><8300,165,225>}
        box {<0,165,-200><8300,190,200>}
}

#declare stair=
union{
        object {tread texture{Stone8 scale<600,600,600>}}
        object {tread texture{Stone8 scale<600,600,600>} translate<450,-200,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<900,-400,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<1350,-600,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<1800,-800,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<2250,-1000,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<2700,-1200,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<3150,-1400,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<3600,-1600,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<4050,-1800,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<4500,-2000,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<4950,-2200,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<5400,-2400,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<5850,-2600,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<6300,-2800,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<6750,-3000,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<7200,-3200,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<7650,-3400,0>}
        object {tread texture{Stone8 scale<600,600,600>} translate<8100,-3600,0>}
        object {rail texture{Stone16 scale<600,600,600>} rotate <0,0,-23.9625> translate <0,1213.8889,4275>}
        object {rail texture{Stone16 scale<600,600,600>} rotate <0,0,-23.9625> translate <0,1213.8889,225>}
}

/* THE FLOOR PATTERN */

#declare pattern_half=
union {
        triangle {<-5500,.1,2500><-3450,.1,2500><-4235.8418,.1,2174.4937> texture {Stone21 scale<400,400,400>}}
        triangle {<-4899.5689,.1,1050.4311><-3450,.1,2500><-4235.8418,.1,2174.4937> texture {Stone24 scale<600,600,600>}}
        triangle {<-4899.5689,.1,1050.4311><-3450,.1,2500><-3775.5063,.1,1714.1582> texture {Stone21 scale<400,400,400>}}
        triangle {<-3450,.1,450><-3450,.1,2500><-3775.5063,.1,1714.1582> texture {Stone24 scale<600,600,600>}}
        triangle {<-3450,.1,450><-3450,.1,2500><-3124.4937,.1,1714.1582> texture {Stone21 scale<400,400,400>}}
        triangle {<-2000.4311,.1,1050.4311><-3450,.1,2500><-3124.4937,.1,1714.1582> texture {Stone24 scale<600,600,600>}}
        triangle {<-2000.4311,.1,1050.4311><-3450,.1,2500><-2664.1582,.1,2174.4937> texture {Stone21 scale<400,400,400>}}
        triangle {<-1400,.1,2500.4311><-3450,.1,2500><-2664.1582,.1,2174.4937> texture {Stone24 scale<600,600,600>}}
        
        triangle {<-4867.9209,.1,2337.2468><-4567.7054,.1,1612.4624><-5343.953,.1,1715.499> texture {Stone3 scale <600,600,600>}}
        triangle {<-4337.5376,.1,1382.2946><-3612.7532,.1,1082.0791><-4234.501,.1,606.047> texture {Stone3 scale <600,600,600>}}
        triangle {<-3287.2468,.1,1082.0791><-2562.4624,.1,1382.2946><-2665.499,.1,606.047> texture {Stone3 scale <600,600,600>}}
        triangle {<-2332.2946,.1,1612.4624><-2032.0791,.1,2337.2468><-1556.047,.1,1715.499> texture {Stone3 scale <600,600,600>}}

        difference {
                cylinder {<-3450,0,2500><-3450,-1000,2500>,2050 texture{Stone8 scale <600,600,600>}}
                box {<-9000,100,2500><9000,-9000,9000> texture{Stone8 scale <600,600,600>}}
        }
        difference {
                cylinder {<-3450,0,2500><-3450,-1000,2500>,2350 texture{Stone19 scale <600,600,600>}}
                cylinder {<-3450,100,2500><-3450,-1100,2500>,2050 texture {Stone19 scale <600,600,600>}}
                box {<-9000,120,2500><9000,-9000,9000> texture {Stone19 scale<600,600,600>}}
        }
}

#declare floor_half=
union {        
        difference {
                union {
                        box {<-7200,0,2500><300,-5,600> texture{Stone8 scale <600,600,600>}}
                        box {<-5900,0,600><-1300,-5,150> texture{Stone8 scale<600,600,600>}}
                }
                cylinder {<-3450,10,2500><-3450,-50,2500>,2350 texture{Stone8 scale<600,600,600>}}
        }
        box {<-7800,0,600><-5900,-5,0> texture{Stone19 scale<600,600,600>}}
        box {<-5900,0,150><-1300,-5,0> texture{Stone19 scale<600,600,600>}}
        box {<-1300,0,600><600,-5,0>   texture{Stone19 scale<600,600,600>}}
        box {<300,0,600><600,-5,2500>  texture{Stone19 scale<600,600,600>}}
}

#declare main_floor=
union {
object {pattern_half}
object {pattern_half rotate<0,180,0> translate<-6900,0,0>}
object {floor_half}
object {floor_half scale <1,1,-1>}
}

/* THE LAMP */

#declare fin=
box {<-10,426,-220><10,526,-170>}

#declare trim=
union {
        torus {87.5,12.5 sturm rotate <90,0,0> translate <0,50,407>}
        cylinder {<0,50,400><0,50,420>,70
        texture{Polished_Brass}
        normal {bump_map {gif "flower.gif" bump_size 5 once}
        scale<140,140,140>
        translate<-70,-20,0>
        }
        }   // add bump map
}

#declare trim2=
union {
        torus {87.5,12.5 sturm rotate <90,0,0> translate <0,50,407>}
        cylinder {<0,50,400><0,50,420>,70}  
}


#declare tilea=
box {<-20,-20,0><20,20,10>
        texture{Polished_Brass}
        texture{pigment{ 
        image_map{gif "tile1.gif" once filter 255,1 filter 0,.5}
        scale<40,40,40>
        translate<-20,-20,0>
        }}
        normal{
        bump_map{gif "tile1.gif" once bump_size 5}
        scale<2,2,2>
        translate<-1,-1,0>
        }
}

#declare tileb=
box {<-20,-20,0><20,20,10>
        texture{Polished_Brass}
        texture{pigment{ 
        image_map{gif "tile2.gif" once filter 255,1 filter 0,.5}
        scale<40,40,40>
        translate<-20,-20,0>
        }}
        normal{
        bump_map{gif "tile2.gif" once bump_size 5}
        scale<2,2,2>
        translate<-1,-1,0>
        }
}

#declare tilec=
union {
        object {tilea translate<0,0,-250>}
        object {tileb translate<0,0,-250> rotate<0,9,0>}
}

#declare tiled=
union {
        object {tilea translate<0,0,-210>}
        object {tileb translate<0,0,-210> rotate<0,11.25,0>}
}

#declare tile_set1=
union {
object {tilec}
object {tilec rotate<0,18,0>}
object {tilec rotate<0,36,0>}   
object {tilec rotate<0,54,0>}   
object {tilec rotate<0,72,0>}   
}

#declare big_ring=
union {
object {tile_set1}
object {tile_set1 rotate<0,90,0>}
object {tile_set1 rotate<0,180,0>}
object {tile_set1 rotate<0,270,0>}
}

#declare tile_set2=
union {
object {tiled}
object {tiled rotate<0,22.5,0>}
object {tiled rotate<0,45,0>}
object {tiled rotate<0,67.5,0>}
}

#declare small_ring=
union {
object {tile_set2}
object {tile_set2 rotate<0,90,0>}
object {tile_set2 rotate<0,180,0>}
object {tile_set2 rotate<0,270,0>}
}

#declare tilea2=
box {<-20,-20,0><20,20,10> texture{Polished_Brass}}

#declare tileb2=
box {<-20,-20,0><20,20,10> texture{Polished_Brass}}

#declare tilec2=
union {
        object {tilea2 translate<0,0,-250>}
        object {tileb2 translate<0,0,-250> rotate<0,9,0>}
}

#declare tiled2=
union {
        object {tilea2 translate<0,0,-210>}
        object {tileb2 translate<0,0,-210> rotate<0,11.25,0>}
}

#declare tile_set12=
union {
object {tilec2}
object {tilec2 rotate<0,18,0>}
object {tilec2 rotate<0,36,0>}   
object {tilec2 rotate<0,54,0>}   
object {tilec2 rotate<0,72,0>}   
}            

#declare big_ring2=
union {
object {tile_set12}
object {tile_set12 rotate<0,90,0>}
object {tile_set12 rotate<0,180,0>}
object {tile_set12 rotate<0,270,0>}
}

#declare tile_set22=
union {
object {tiled2}
object {tiled2 rotate<0,22.5,0>}
object {tiled2 rotate<0,45,0>}
object {tiled2 rotate<0,67.5,0>}
}

#declare small_ring2=
union {
object {tile_set22}
object {tile_set22 rotate<0,90,0>}
object {tile_set22 rotate<0,180,0>}
object {tile_set22 rotate<0,270,0>}
}

#declare lamp_base=
union {
        sphere {<0,0,0>,395 texture{Polished_Brass} normal {dents .75 scale<15,15,15>}}
        cylinder {<0,-50,0><0,150,0>,407}
        sphere {<0,-374,0>,150}
        cylinder {<0,346,0><0,426,0>,250}
        difference {
                union {
                        cylinder {<0,526,0><0,566,0>,250}
                        cylinder {<0,566,0><0,586,0>,225}
                }
                cylinder {<0,0,0><0,700,0>,150}
        }
        object {fin}
        object {fin rotate <0,22.5,0>}
        object {fin rotate <0,45,0>}
        object {fin rotate <0,67.5,0>}
        object {fin rotate <0,90,0>}
        object {fin rotate <0,112.5,0>}
        object {fin rotate <0,135,0>}
        object {fin rotate <0,157.5,0>}
        object {fin rotate <0,180,0>}
        object {fin rotate <0,202.5,0>}
        object {fin rotate <0,225,0>}
        object {fin rotate <0,247.5,0>}
        object {fin rotate <0,270,0>}
        object {fin rotate <0,292.5,0>}
        object {fin rotate <0,315,0>}
        object {fin rotate <0,337.5,0>}
        object {trim}
        object {trim rotate <0,22.5,0>}
        object {trim rotate <0,45,0>}
        object {trim rotate <0,67.5,0>}
        object {trim rotate <0,90,0>}
        object {trim rotate <0,112.5,0>}
        object {trim rotate <0,135,0>}
        object {trim rotate <0,157.5,0>}
        object {trim rotate <0,180,0>}
        object {trim rotate <0,202.5,0>}
        object {trim rotate <0,225,0>}
        object {trim rotate <0,247.5,0>}
        object {trim rotate <0,270,0>}
        object {trim rotate <0,292.5,0>}
        object {trim rotate <0,315,0>}
        object {trim rotate <0,337.5,0>}
        object {big_ring translate<0,326,0>}
        object {small_ring translate<0,-354.5,0>}
        light_source {<0,530,0> color soft_light}
}

#declare lamp_base2=
union {
        sphere {<0,0,0>,395 texture{Polished_Brass} normal {dents .75 scale<15,15,15>}}
        cylinder {<0,-50,0><0,150,0>,407}
        sphere {<0,-374,0>,150}
        cylinder {<0,346,0><0,426,0>,250}
        difference {
                union {
                        cylinder {<0,526,0><0,566,0>,250}
                        cylinder {<0,566,0><0,586,0>,225}
                }
                cylinder {<0,0,0><0,700,0>,150}
        }
        object {fin}
        object {fin rotate <0,22.5,0>}
        object {fin rotate <0,45,0>}
        object {fin rotate <0,67.5,0>}
        object {fin rotate <0,90,0>}
        object {fin rotate <0,112.5,0>}
        object {fin rotate <0,135,0>}
        object {fin rotate <0,157.5,0>}
        object {fin rotate <0,180,0>}
        object {fin rotate <0,202.5,0>}
        object {fin rotate <0,225,0>}
        object {fin rotate <0,247.5,0>}
        object {fin rotate <0,270,0>}
        object {fin rotate <0,292.5,0>}
        object {fin rotate <0,315,0>}
        object {fin rotate <0,337.5,0>}
        object {trim}
        object {trim2 rotate <0,22.5,0>}
        object {trim2 rotate <0,45,0>}
        object {trim2 rotate <0,67.5,0>}
        object {trim2 rotate <0,90,0>}
        object {trim2 rotate <0,112.5,0>}
        object {trim2 rotate <0,135,0>}
        object {trim2 rotate <0,157.5,0>}
        object {trim2 rotate <0,180,0>}
        object {trim2 rotate <0,202.5,0>}
        object {trim2 rotate <0,225,0>}
        object {trim2 rotate <0,247.5,0>}
        object {trim2 rotate <0,270,0>}
        object {trim2 rotate <0,292.5,0>}
        object {trim2 rotate <0,315,0>}
        object {trim2 rotate <0,337.5,0>}
        object {big_ring2 translate<0,326,0>}
        object {small_ring2 translate<0,-354.5,0>}
        light_source {<0,530,0> color soft_light}
}


#declare lamp_arm=
union{
        difference {
                cylinder {<0,276.3821,25><0,276.3821,-25>,676.2244}
                cylinder {<0,276.3821,30><0,276.3821,-30>,666.2244}
                box {<-9000,0,-9000><9000,9000,9000> rotate<0,0,21> translate<-720,0,0>}
                box {<-9000,0,-9000><9000,9000,9000> rotate<0,0,-21> translate<720,0,0>}
        }
        difference {
                cylinder {<-720,0,25><-720,0,-25>,105}
                cylinder {<-720,0,30><-720,0,-30>,95}
                box {<-9000,0,-9000><9000,-9000,9000> rotate<0,0,21> translate<-720,0,0>}
        }
        difference {
                cylinder {<720,0,25><720,0,-25>,105}
                cylinder {<720,0,30><720,0,-30>,95}
                box {<-9000,0,-9000><9000,-9000,9000> rotate<0,0,-21> translate<720,0,0>}
        }
        difference {
                cylinder {<440.2111,-133.4456,25><440.2111,-133.4456,-25>,65}
                cylinder {<440.2111,-133.4456,30><440.2111,-133.4456,-30>,55}
        }
        difference {
                cylinder {<-440.2111,-133.4456,25><-440.2111,-133.4456,-25>,65}
                cylinder {<-440.2111,-133.4456,30><-440.2111,-133.4456,-30>,55}
        }
}

#declare link=
union {
        torus {50,10 sturm rotate <90,0,0>}
        box {<-25,42.5,12.5><25,97.5,22.5>}
        box {<-25,42.5,-12.5><25,97.5,-22.5>}
        difference {
                cylinder {<25,42.5,0><-25,42.5,0>,22.5}
                cylinder {<30,42.5,0><-30,42.5,0>,12.5}
                box {<40,42.5,40><-40,-100,-40>}
        }
        difference {
                cylinder {<25,97.5,0><-25,97.5,0>,22.5}
                cylinder {<30,97.5,0><-30,97.5,0>,22.5}
                box {<40,97.5,40><-40,0,-40>}
        }
}

#declare chain1=
union {
        object {link}
        object {link translate <0,140,0>}
        object {link translate <0,280,0>}
        object {link translate <0,420,0>}
        object {link translate <0,560,0>}
        object {link translate <0,700,0>}
        object {link translate <0,840,0>}
        object {link translate <0,980,0>}
        object {link translate <0,1120,0>}
        object {link translate <0,1260,0>}
        object {link translate <0,1400,0>}
}

#declare chain2=
union {
        object {link}
        object {link translate <0,140,0>}
        object {link translate <0,280,0>}
        object {link translate <0,420,0>}
        object {link translate <0,560,0>}
        object {link translate <0,700,0>}
        object {link translate <0,840,0>}
        object {link translate <0,980,0>}
        object {link translate <0,1120,0>}
        object {link translate <0,1260,0>}
}

#declare lamp=
union {
object {lamp_base texture{Polished_Brass}}
object {lamp_arm texture{Polished_Brass}}
object {lamp_arm texture{Polished_Brass} rotate<0,90,0>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259> rotate<0,90,0>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259> rotate<0,180,0>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259> rotate<0,270,0>}
object {chain2 texture{Polished_Brass} translate<0,1511.3213,0>}
torus {45.055,10 sturm texture{Polished_Brass} translate<0,1481.3213,0>}
torus {75,10 sturm texture{Polished_Brass} rotate<90,0,0> translate<0,2936.3213,0>}
box {<100,2950,100><-100,3025,-100> texture{Polished_Brass}}
}

#declare lamp2=
union {
object {lamp_base2 texture{Polished_Brass}}
object {lamp_arm texture{Polished_Brass}}
object {lamp_arm texture{Polished_Brass} rotate<0,90,0>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259> rotate<0,90,0>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259> rotate<0,180,0>}
object {chain1 texture{Polished_Brass} rotate<25,0,0> translate<0,124.1254,-677.9259> rotate<0,270,0>}
object {chain2 texture{Polished_Brass} translate<0,1511.3213,0>}
torus {45.055,10 sturm texture{Polished_Brass} translate<0,1481.3213,0>}
torus {75,10 sturm texture{Polished_Brass} rotate<90,0,0> translate<0,2936.3213,0>}
box {<100,2950,100><-100,3025,-100> texture{Polished_Brass}}
}

/* THE REPEATING BAY */

#declare bay=
union{
box {<-7800,-40000,-300><-6600,200000,300> texture{Stone8 scale <600,600,600>} texture{tex3}}
box {<-600,-40000,-300><600,200000,300> texture{Stone8 scale <600,600,600>} texture{tex3}}
box {<6600,-40000,-300><7800,200000,300> texture{Stone8 scale <600,600,600>} texture{tex3}}
box {<13800,-40000,-300><15000,200000,300> texture{Stone8 scale <600,600,600>} texture{tex3}}

object {main_floor}
box {<0,-40000,-2500><600,-5,2500> texture{Stone8 scale <600,600,600>} texture{tex3}}

box {<-6600,-40000,250><-6150,3539.9293,-250> texture{Stone8 scale <600,600,600>} texture{tex3}}
box {<-1050,-40000,250><-600,1929.2342,-250> texture{Stone8 scale <600,600,600>} texture{tex3}}
box {<600,-40000,250><1050,1607.6952,-250> texture{Stone8 scale <600,600,600>} texture{tex3}}
box {<6150,-40000,250><6600,0,-250> texture{Stone8 scale <600,600,600>} texture{tex3}}
box {<7800,-40000,250><8250,-321.539,-250> texture{Stone8 scale<600,600,600>} texture{tex3}}

object {arch translate <-4563.3807,7629.7207,0>}
object {arch translate <-4563.3807,2736.9270,0>}
object {arch translate <2636.6193,807.6929,0>}
object {arch translate <2636.6193,5700.4865,0>}
object {arch translate <2636.6193,16000,0>}
object {arch translate <9836.6193,-1121.5413,0>}


object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <-6400,3536.9293,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <-6400,8429.7230,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <-800,1929.2342,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <-800,6822.0278,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <800,1607.6952,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <800,6500.4888,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <6400,0,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <6400,4892.7936,0>}
object {column texture{Stone8 scale<600,600,600>} rotate <0,90,0> translate <8000,-321.539,0>}

}

/* SPECIAL LAMP GROUP */

#declare lamp_group=
union {
object {lamp2 translate<3600,1799.3814,0>}
object {lamp2 translate<-3600,3728.6156,0>}
}

/* THE FINAL SCENE */

object {lamp_group}
object {lamp translate<3600,1799.3814,-5000>}
object {lamp2 translate<3600,1799.3814,5000>}
object {lamp2 translate<3600,1799.3814,15000>}
object {lamp2 translate<3600,1799.3814,25000>}
object {lamp2 translate<3600,1799.3814,45000>}

object {bay translate <0,0,-5000>}
object {bay}
object {bay translate <0,0,5000>}
object {bay translate <0,0,10000>}
object {bay translate <0,0,15000>}
object {bay translate <0,0,20000>}
object {bay translate <0,0,25000>}
object {bay translate <0,0,30000>}
object {bay translate <0,0,35000>}
object {bay translate <0,0,40000>}
object {bay translate <0,0,45000>}
object {bay translate <0,0,50000>}

object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,5300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,10300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,15300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,20300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,25300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,30300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,35300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,40300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,45300>}
object {balustrade texture{Stone8 scale <600,600,600>} translate <375,0,50300>}

object {stair translate <600,0,-4750>}

box {<-7200,-4000,-60000><-8000,20000,60000> finish {Mirror}}

plane {y,-3500 texture{Water scale<3000,3000,3000>}}

fog {color White distance 30000}

/* THE BOAT */

#declare boat_base=
difference {
        difference {
                intersection {
                        sphere {<2812.5,0,0>,3312.5}
                        sphere {<-2812.5,0,0>,3312.5}
                }
                intersection {
                        sphere {<2812.5,0,0>,3212.5}
                        sphere {<-2812.5,0,0>,3212.5}
                }
        }
        sphere {<0,7556.25,0>,7756.25}
}

#declare boat_house=
union {
        difference {
                union {
                        box {<361,0,0><-361,201,-800>}
                        box {<169,169,0><-169,-169,-800> rotate<0,0,45> translate<0,201,0>}
                }
                difference {
                        box {<169,169,10><-160,-160,-810> rotate<0,0,45> translate<0,101,0>}
                        box {<900,101,900><-900,-900,-900>}
                }
        }
}

#declare boat=
union {
object {boat_base texture{DMFWood1 scale<600,600,900>} scale<1,.5,1>}
object {boat_house texture{DMFWood3 scale<600,600,900>} translate<0,0,1750>}
light_source {<0,-200,-800> color soft_light}
}

object {boat rotate<0,-135,0> translate<11000,-2700,4200>}

